``ExposoGraph.models``
======================

Pydantic data models for nodes, edges, and the knowledge graph container.

Enums
-----

.. autoclass:: ExposoGraph.models.NodeType
   :members:
   :undoc-members:

.. autoclass:: ExposoGraph.models.EdgeType
   :members:
   :undoc-members:

.. autoclass:: ExposoGraph.models.CurationStatus
   :members:
   :undoc-members:

.. autoclass:: ExposoGraph.models.CurationConfidence
   :members:
   :undoc-members:

.. autoclass:: ExposoGraph.models.RecordOrigin
   :members:
   :undoc-members:

.. autoclass:: ExposoGraph.models.MatchStatus
   :members:
   :undoc-members:

Models
------

.. autoclass:: ExposoGraph.models.ProvenanceRecord
   :members:
   :show-inheritance:

.. autoclass:: ExposoGraph.models.CurationRecord
   :members:
   :show-inheritance:

.. autoclass:: ExposoGraph.models.Node
   :members:
   :show-inheritance:

.. autoclass:: ExposoGraph.models.Edge
   :members:
   :show-inheritance:

.. autoclass:: ExposoGraph.models.KnowledgeGraph
   :members:
   :show-inheritance:
